Coverage for /home/ken/src/shared/avendesora/avendesora/collection.py: 0%

# Coverage for /home/ken/src/shared/avendesora/avendesora/collection.py : 0%

## 27 statements 0 run 27 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 | # Collections # # Provides common interface for dictionaries and lists. If a string is passed # in, it is split and then treated as a list. Optimized for convenience rather # than for large collections. Sorting versus the key is used to avoid randomness # in the ordering of the dictionary-based collections. # License {{{1 # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with this program. If not, see http://www.gnu.org/licenses/. # Imports {{{1 from inform import is_str, is_collection # Collection {{{1 class Collection(object): def __init__(self, collection, splitter=None): if is_str(collection): self.collection = collection.split(splitter) elif is_collection(collection): self.collection = collection else: # is scalar self.collection = {None: collection} def keys(self): try: return self.collection.keys() except AttributeError: return range(len(self.collection)) def values(self): try: return [self.collection[k] for k in sorted(self.collection.keys())] except AttributeError: return self.collection def items(self): try: return [(k, self.collection[k]) for k in sorted(self.collection.keys())] except AttributeError: return enumerate(self.collection) def __contains__(self, item): return item in self.values() def __iter__(self): return iter(self.values())